* Generic session options - set page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=120 formdlim='-';                                            
* Kill default titles on output; 
TITLE; ODS LISTING;

***********************************************************************************;
*******    MACRO PROGRAMS TO AUTOMATE CALCULATIONS FOR EXAMPLE 2-3          *******;
*******               NOTHING IN HERE NEEDS TO BE CHANGED                   *******;
***********************************************************************************;

* To use FitTest macro;
* FitFewer = Name of ODS InfoCrit table for nested model;
* FitMore  = Name of ODS InfoCrit table for comparison model;
%MACRO FitTest(FitFewer=,FitMore=);
DATA &FitFewer.; LENGTH Name $30.; SET &FitFewer.; Name="&FitFewer."; RUN;
DATA &FitMore.;  LENGTH Name $30.; SET &FitMore.;  Name="&FitMore.";  RUN;
DATA FitCompare; LENGTH Name $30.; SET &FitFewer. &FitMore.; RUN;
DATA FitCompare; SET FitCompare; DevDiff=Lag1(Neg2LogLike)-Neg2LogLike;
     DFdiff=Parms-LAG1(Parms); Pvalue=1-PROBCHI(DevDiff,DFdiff);
     DROP AICC HQIC CAIC; RUN;
TITLE9 "Likelihood Ratio Test for &FitFewer. vs. &FitMore.";
PROC PRINT NOOBS DATA=FitCompare; RUN; TITLE9;
%MEND FitTest;

* To use TotalR2 macro;
* DV =        Case-sensitive name of dependent variable;
* PredFewer = Name of OUTPM= data file of predicted outcomes for nested model;
* PredMore =  Name of OUTPM= data file of predicted outcomes for comparison model;
%MACRO TotalR2(DV=,PredFewer=,PredMore=);
PROC CORR NOPRINT NOSIMPLE DATA=&PredFewer. OUTP=CorrFewer; VAR pred &DV.; RUN;
PROC CORR NOPRINT NOSIMPLE DATA=&PredMore.  OUTP=CorrMore;  VAR pred &DV.; RUN;
DATA CorrFewer; LENGTH Name $30.; SET CorrFewer; Name="&PredFewer."; RUN;
DATA CorrMore;  LENGTH Name $30.; SET CorrMore;  Name="&PredMore.";  RUN;
DATA CorrCompare; LENGTH Name $30.; SET CorrFewer CorrMore; 
     PredCorr=Pred; TotalR2=PredCorr*PredCorr; 
     IF _NAME_="Pred" OR MISSING(_NAME_)=1 THEN DELETE; DROP Pred; RUN;
DATA CorrCompare; SET CorrCompare; TotalR2Diff=TotalR2-LAG1(TotalR2);
     KEEP Name PredCorr TotalR2 TotalR2Diff; RUN; 
TITLE9 "Total R2 (% Reduction) for &PredFewer. vs. &PredMore.";
PROC PRINT NOOBS DATA=CorrCompare; RUN; TITLE9; 
%MEND TotalR2;

* To use PseudoR2 macro;
* Ncov =     TOTAL # entries in covariance parameter estimates table;
* CovFewer = Name of ODS CovParms table for nested model;
* CovMore =  Name of ODS CovParms table for comparison model;
%MACRO PseudoR2(NCov=,CovFewer=,CovMore=);
DATA &CovFewer.; LENGTH Name $30.; SET &CovFewer.; Name="&CovFewer."; RUN;
DATA &CovMore.;  LENGTH Name $30.; SET &CovMore.;  Name="&CovMore.";  RUN;
DATA CovCompare; LENGTH Name $30.; SET &CovFewer. &CovMore.; RUN;
DATA CovCompare; SET CovCompare; 
     PseudoR2=(LAG&Ncov.(Estimate)-Estimate)/LAG&Ncov.(Estimate); RUN;
DATA CovCompare; SET CovCompare; 
     IF CovParm IN("UN(2,1)","UN(3,1)","UN(4,1)","UN(3,2)","UN(4,2)","UN(4,3)") 
     THEN DELETE; RUN;
TITLE9 "PsuedoR2 (% Reduction) for &CovFewer. vs. &CovMore.";
PROC PRINT NOOBS DATA=CovCompare; RUN; TITLE9;
%MEND PseudoR2;

******************************************************************************;
******          EXAMPLE 1 MODELS (FROM CHAPTER 7B)                      ******;
******************************************************************************;

* Define global variable for file location -- CHANGE THIS TO YOUR DIRECTORY;
%LET example=C:\Dropbox\Workshop_OSU_2018\Download\SAS;
LIBNAME example "&example.";

* Import chapter 7b multivariate data in work library;
DATA work.Example1multiv; SET example.Example1; RUN;

* Stack multivariate data;
DATA work.Example1; SET work.Example1multiv;
occasion=12; age=age12; risky=risky12; monitor=monitor12; OUTPUT;
occasion=13; age=age13; risky=risky13; monitor=monitor13; OUTPUT;
occasion=14; age=age14; risky=risky14; monitor=monitor14; OUTPUT;
occasion=15; age=age15; risky=risky15; monitor=monitor15; OUTPUT;
occasion=16; age=age16; risky=risky16; monitor=monitor16; OUTPUT;
occasion=17; age=age17; risky=risky17; monitor=monitor17; OUTPUT;
occasion=18; age=age18; risky=risky18; monitor=monitor18; OUTPUT;
* Drop old unnecessary multivariate variables;
DROP age12-age18 risky12-risky18 monitor12-monitor18;
LABEL   
occasion = "occasion: Occasion of Measurement (12-18)"
age = "age: Exact Age at Occasion"
risky = "risky: Risky Behavior at Occasion"
monitor = "monitor: Monitoring at Occasion";
RUN;

* Center predictors for analysis in stacked data;
DATA work.Example1; SET work.Example1;
agec18 = age - 18;
att4 = attitude12 - 4;
LABEL
agec18 = "agec18: Exact Age (0=18)"
att4 = "att4: Age 12 Attitudes (0=4)";
* Subset sample to complete cases for all eventual predictors in chapter 9;
IF NMISS(agec18, att4, risky, monitor)>0 THEN DELETE;
RUN;
     
* Save SAS syntax and output to permanent text file;
PROC PRINTTO PRINT="&example.\Example1_SAS_Output.txt" 
             LOG=  "&example.\Example1_SAS_Output.txt"; RUN;

TITLE1 'SAS Model 0: Saturated Means by Rounded Occasion, Unstructured Variance Model';
PROC MIXED DATA=work.Example1 COVTEST NOCLPRINT NAMELEN=100 IC METHOD=ML;
     CLASS PersonID occasion;
     MODEL risky = occasion / SOLUTION DDFM=Satterthwaite;
     REPEATED occasion / R RCORR TYPE=UN SUBJECT=PersonID;
     LSMEANS occasion / DIFF=ALL;
RUN; TITLE1;
 
TITLE1 'SAS Model 1: Empty Means, Random Intercept Model';
PROC MIXED DATA=work.Example1 COVTEST NOCLPRINT NAMELEN=100 IC METHOD=ML;
     CLASS PersonID;
     MODEL risky =  / SOLUTION DDFM=Satterthwaite OUTPM=PredEmpty;
     RANDOM INTERCEPT / G V VCORR TYPE=UN SUBJECT=PersonID;
     ODS OUTPUT CovParms=CovEmpty;
RUN; TITLE1;
 
TITLE1 'SAS Model 2s: Fixed Linear Age, Random Intercept Model';
PROC MIXED DATA=work.Example1 COVTEST NOCLPRINT NAMELEN=100 IC METHOD=ML;
     CLASS PersonID;
     MODEL risky = agec18 / SOLUTION DDFM=Satterthwaite;
     RANDOM INTERCEPT / TYPE=UN SUBJECT=PersonID;
     ODS OUTPUT CovParms=CovFixLin InfoCrit=FitFixLin;
     ESTIMATE 'Intercept at Age=12'    intercept 1 agec18 -6;
     ESTIMATE 'Intercept at Age=13'    intercept 1 agec18 -5;
     ESTIMATE 'Intercept at Age=14'    intercept 1 agec18 -4;
     ESTIMATE 'Intercept at Age=15'    intercept 1 agec18 -3;
     ESTIMATE 'Intercept at Age=16'    intercept 1 agec18 -2;
     ESTIMATE 'Intercept at Age=17'    intercept 1 agec18 -1;
     ESTIMATE 'Intercept at Age=18'    intercept 1 agec18  0;
RUN; TITLE1;
     * Call macro to calculate pseudo R2;
     %PseudoR2(NCov=2, CovFewer=CovEmpty, CovMore=CovFixLin);
 
TITLE1 'SAS Model 2b: Random Linear Age Model';
PROC MIXED DATA=work.Example1 COVTEST NOCLPRINT NAMELEN=100 IC METHOD=ML;
     CLASS PersonID;
     MODEL risky = agec18 / SOLUTION DDFM=Satterthwaite;
     RANDOM INTERCEPT agec18 / G GCORR V VCORR TYPE=UN SUBJECT=PersonID;
     ODS OUTPUT CovParms=CovRandLin InfoCrit=FitRandLin;
     ESTIMATE 'Intercept at Age=12'    intercept 1 agec18 -6;
     ESTIMATE 'Intercept at Age=13'    intercept 1 agec18 -5;
     ESTIMATE 'Intercept at Age=14'    intercept 1 agec18 -4;
     ESTIMATE 'Intercept at Age=15'    intercept 1 agec18 -3;
     ESTIMATE 'Intercept at Age=16'    intercept 1 agec18 -2;
     ESTIMATE 'Intercept at Age=17'    intercept 1 agec18 -1;
     ESTIMATE 'Intercept at Age=18'    intercept 1 agec18  0;
RUN; TITLE1;
     * Call macro to calculate LRT for nested models;
     %FitTest(FitFewer=FitFixLin, FitMore=FitRandLin);
 
TITLE1 'SAS Model 2c: Fixed Quadratic, Random Linear Age Model';
PROC MIXED DATA=work.Example1 COVTEST NOCLPRINT NAMELEN=100 IC METHOD=ML;
     CLASS PersonID;
     MODEL risky = agec18 agec18*agec18 / SOLUTION DDFM=Satterthwaite OUTPM=PredAge;
     RANDOM INTERCEPT agec18 / TYPE=UN SUBJECT=PersonID;
     ODS OUTPUT CovParms=CovFixQuad InfoCrit=FitFixQuad;
     ESTIMATE 'Intercept at Age=12'              intercept 1 agec18 -6 agec18*agec18 36;
     ESTIMATE 'Intercept at Age=13'              intercept 1 agec18 -5 agec18*agec18 25;
     ESTIMATE 'Intercept at Age=14'              intercept 1 agec18 -4 agec18*agec18 16;
     ESTIMATE 'Intercept at Age=15'              intercept 1 agec18 -3 agec18*agec18 9;
     ESTIMATE 'Intercept at Age=16'              intercept 1 agec18 -2 agec18*agec18 4;
     ESTIMATE 'Intercept at Age=17'              intercept 1 agec18 -1 agec18*agec18 1;
     ESTIMATE 'Intercept at Age=18'              intercept 1 agec18 0  agec18*agec18 0;
     ESTIMATE 'Linear Slope at Age=12'           agec18 1 agec18*agec18 -12;
     ESTIMATE 'Linear Slope at Age=13'           agec18 1 agec18*agec18 -10;
     ESTIMATE 'Linear Slope at Age=14'           agec18 1 agec18*agec18 -8;
     ESTIMATE 'Linear Slope at Age=15'           agec18 1 agec18*agec18 -6;
     ESTIMATE 'Linear Slope at Age=16'           agec18 1 agec18*agec18 -4;
     ESTIMATE 'Linear Slope at Age=17'           agec18 1 agec18*agec18 -2;
     ESTIMATE 'Linear Slope at Age=18'           agec18 1 agec18*agec18  0;
RUN; TITLE1;
     * Call macro to calculate pseudo R2;
     %PseudoR2(NCov=4, CovFewer=CovRandLin, CovMore=CovFixQuad);
     * Call macro to calculate Total R2 for overall model;
     %TotalR2(DV=risky, PredFewer=PredEmpty, PredMore=PredAge);
 
TITLE1 'SAS Model 2d: Random Quadratic Age Model';
PROC MIXED DATA=work.Example1 COVTEST NOCLPRINT NAMELEN=100 IC METHOD=ML;
     CLASS PersonID;
     MODEL risky = agec18 agec18*agec18 / SOLUTION DDFM=Satterthwaite;
     RANDOM INTERCEPT agec18 agec18*agec18 / G GCORR V VCORR TYPE=UN SUBJECT=PersonID;
     ODS OUTPUT InfoCrit=FitRandQuad;
     ESTIMATE 'Intercept at Age=12'              intercept 1 agec18 -6 agec18*agec18 36;
     ESTIMATE 'Intercept at Age=13'              intercept 1 agec18 -5 agec18*agec18 25;
     ESTIMATE 'Intercept at Age=14'              intercept 1 agec18 -4 agec18*agec18 16;
     ESTIMATE 'Intercept at Age=15'              intercept 1 agec18 -3 agec18*agec18 9;
     ESTIMATE 'Intercept at Age=16'              intercept 1 agec18 -2 agec18*agec18 4;
     ESTIMATE 'Intercept at Age=17'              intercept 1 agec18 -1 agec18*agec18 1;
     ESTIMATE 'Intercept at Age=18'              intercept 1 agec18 0  agec18*agec18 0;
     ESTIMATE 'Linear Slope at Age=12'           agec18 1 agec18*agec18 -12;
     ESTIMATE 'Linear Slope at Age=13'           agec18 1 agec18*agec18 -10;
     ESTIMATE 'Linear Slope at Age=14'           agec18 1 agec18*agec18 -8;
     ESTIMATE 'Linear Slope at Age=15'           agec18 1 agec18*agec18 -6;
     ESTIMATE 'Linear Slope at Age=16'           agec18 1 agec18*agec18 -4;
     ESTIMATE 'Linear Slope at Age=17'           agec18 1 agec18*agec18 -2;
     ESTIMATE 'Linear Slope at Age=18'           agec18 1 agec18*agec18  0;
RUN; TITLE1;
     * Call macro to calculate LRT for nested models;
     %FitTest(FitFewer=FitFixQuad, FitMore=FitRandQuad);
  
TITLE1 'SAS Model 3: Fixed Quadratic, Random Linear Age Model';
TITLE2 'Attitudes Predicting Quadratic Age Slope';
PROC MIXED DATA=work.Example1 COVTEST NOCLPRINT NAMELEN=100 IC METHOD=ML;
     CLASS PersonID;
     MODEL risky = agec18 agec18*agec18
                   att4 agec18*att4 agec18*agec18*att4
                    / SOLUTION DDFM=Satterthwaite OUTPM=PredAttQuad;
     RANDOM INTERCEPT agec18 / TYPE=UN SUBJECT=PersonID;
     ODS OUTPUT CovParms=CovAttQuad;
RUN; TITLE1; TITLE2;
     * Call macro to calculate pseudo R2;
     %PseudoR2(NCov=4, CovFewer=CovFixQuad, CovMore=CovAttQuad);
     * Call macro to calculate Total R2 for overall model;
     %TotalR2(DV=risky, PredFewer=PredAge, PredMore=PredAttQuad);
 
* Close output;
PROC PRINTTO; RUN;

* Trimming data to send just needed variables to Mplus;
DATA work.Example1Mplus; SET work.Example1; 
agesq=agec18*agec18;
* Telling it which variables to keep -- handy to use this in Mplus;
KEEP PersonID occasion risky agec18 att4 mon3 agesq;
* Replace any missing values with -999;
	ARRAY avars(7) PersonID occasion risky agec18 att4 agesq mon3;
		DO i=1 TO 7; IF avars(i)=. THEN avars(i)=-999; END; DROP i;
RUN;

* Export to .csv for use in Mplus MLM syntax;
PROC EXPORT DATA=work.Example1Mplus OUTFILE= "&filesave.\Example1.csv" 
	DBMS=CSV REPLACE; PUTNAMES=NO; RUN;
