* Output options: all can be turned on/off by adding or removing the 'NO':
  page number, date, centering, or page breaks, page length and width; 
  OPTIONS nonumber nodate nocenter formdlim='-' pagesize=MAX linesize=MAX spool; 
* Eliminate SAS default titles and names of tables in output (TRACE ON to show);
  TITLE; ODS TRACE OFF; ODS LISTING;

* To use FitTest macro;
* FitFewer = Name of ODS InfoCrit table for nested model;
* FitMore  = Name of ODS InfoCrit table for comparison model;
%MACRO FitTest(FitFewer=,FitMore=);
DATA &FitFewer.; LENGTH Name $30.; SET &FitFewer.; Name="&FitFewer."; RUN;
DATA &FitMore.;  LENGTH Name $30.; SET &FitMore.;  Name="&FitMore.";  RUN;
DATA FitCompare; LENGTH Name $30.; SET &FitFewer. &FitMore.; RUN;
DATA FitCompare; SET FitCompare; DevDiff=Lag1(Neg2LogLike)-Neg2LogLike;
     DFdiff=Parms-LAG1(Parms); Pvalue=1-PROBCHI(DevDiff,DFdiff);
     DROP AICC HQIC CAIC; RUN;
TITLE9 "Likelihood Ratio Test for &FitFewer. vs. &FitMore.";
PROC PRINT NOOBS DATA=FitCompare; RUN; TITLE9;
%MEND FitTest;

* Defining global variable for file location to be replaced in code below;
%LET example=C:\Dropbox\Workshop_OSU_2018\Download\SAS;
* Location for SAS files for these models (uses macro variable filesave);
LIBNAME example "&example.";

* Import chapter 8 stacked data into work library;
DATA work.Example3; SET example.Example3; RUN;

* Create person means across time;
PROC SORT DATA=work.Example3; BY PersonID session; RUN;
PROC MEANS NOPRINT DATA=work.Example3; BY PersonID;
     VAR women baseage mood stressor;
     OUTPUT OUT=work.PersonMeans 
     MEAN(women baseage mood stressor) = PMwomen PMbaseage PMmood PMstressor;
RUN;

* Merge person means back into original data;
DATA work.Example3; 
MERGE work.Example3 work.PersonMeans(DROP= _TYPE_ _FREQ_ PMwomen PMbaseage); 
BY PersonID;
LABEL   
PMmood = "PMmood: Person Mean Negative Mood"
PMstressor = "PMstressor: Person Mean Stressors";
* Create centered predictors for analysis;
age80 = baseage - 80;
mood2 = mood - 2;
WPmood = mood - PMmood;
PMmood2 = PMmood - 2;
WPstressor = stressor - PMstressor;
PMstressor40 = PMstressor - .40;
LABEL
age80 = "age80: Baseline Age (0=80)"
mood2 = "mood2: Daily Negative Mood (0=2)"
WPmood = "WPmood: Within-Person Negative Mood (0=PM)"
PMmood2 = "PMmood2: Person Mean Negative Mood (0=2)"
WPstressor = "WPstressor: Within-Person Stressors (0=PM)"
PMstressor40 = "PMstressor40: Mean #Days with Stressor (0=0.40)";
* Subset sample to complete cases for all predictors;
IF NMISS(women, baseage, symptoms, mood, stressor, mood)>0 THEN DELETE;
* Subset sample to study days within a two-week period;
IF studyday>14 THEN DELETE;
RUN; 

******************************************************************************;
*** NOTE: WE ARE USING ML INSTEAD OF REML TO GET COMPARABLE RESULTS TO MPLUS;
*** BEGIN MEDIATION MODELS HERE;
******************************************************************************;

* Save SAS syntax and output to permanent text file;
PROC PRINTTO PRINT="&example.\Example3_SAS_Output.txt" 
             LOG=  "&example.\Example3_SAS_Output.txt"; RUN;

TITLE1 "Step 1: WP and BP Contextual BP Stress 
        Predicting Symptoms: X --> Y";
PROC MIXED DATA=work.Example3 COVTEST NOCLPRINT IC 
        NAMELEN=50 METHOD=ML;
 CLASS PersonID;
 MODEL symptoms = women age80 women*age80 
                  stressor PMstress40
                   / SOLUTION DDFM=SATTERTHWAITE;
 RANDOM INTERCEPT / TYPE=UN SUBJECT=PersonID;
 ESTIMATE "BP X to Y Effect" stressor 1 PMstress40 1;
RUN;

TITLE1 "Step 2: WP and BP Contextual Mood 
        Predicting Symptoms: M --> Y";
PROC MIXED DATA=work.Example3 COVTEST NOCLPRINT IC 
         NAMELEN=50 METHOD=ML;
 CLASS PersonID;
 MODEL symptoms = women age80 women*age80 mood2 PMmood2 
                  / SOLUTION DDFM=SATTERTHWAITE;
 RANDOM INTERCEPT / TYPE=UN SUBJECT=PersonID;
 ESTIMATE "BP M to Y Effect" mood2 1 PMmood2 1;
RUN;

* Close output;
PROC PRINTTO; RUN;

* Trimming data to send just needed variables to Mplus;
DATA work.Example3Mplus; * RETAIN re-orders variables as listed;
	RETAIN PersonID women age80 session symptoms mood2 stressor PMstressor40;
	SET work.Example3;
	* Telling it which variables to keep -- handy to use this in Mplus;
	KEEP PersonID women age80 session symptoms mood2 stressor PMstressor40;
	* Replace any missing values with -999;
	ARRAY avars(8) PersonID women age80 session symptoms mood2 stressor PMstressor40;
		DO i=1 TO 8; IF avars(i)=. THEN avars(i)=-999; END; DROP i; 
RUN;

* Export to .csv for use in Mplus MLM syntax;
PROC EXPORT DATA=work.Example3Mplus OUTFILE= "&example.\Example3.csv" 
	DBMS=CSV REPLACE; PUTNAMES=NO; RUN;
