* Output options: all can be turned on/off by adding or removing the NO;
* page number, date, centering, or page breaks, page length and width;
OPTIONS NOnumber NOdate NOcenter FormDlim=' ' PageSize=MAX LineSize=MAX;
* Eliminate SAS default titles and names of tables in output (TRACE ON to show);
TITLE; ODS TRACE OFF; ODS LISTING;

* Defining global variable for file location to be replaced in code below;
%LET example=C:\Dropbox\Workshop_OSU_2018\Download\SAS;
* Location for SAS files for these models (uses macro variable filesave);
LIBNAME example "&example.";

* Import chapter 9 multivariate data in work library;
DATA work.Example4multiv; SET example.Example4; RUN;

* Stack multivariate data;
DATA work.Example4; SET work.Example4multiv;
occasion=12; age=age12; risky=risky12; monitor=monitor12; OUTPUT;
occasion=13; age=age13; risky=risky13; monitor=monitor13; OUTPUT;
occasion=14; age=age14; risky=risky14; monitor=monitor14; OUTPUT;
occasion=15; age=age15; risky=risky15; monitor=monitor15; OUTPUT;
occasion=16; age=age16; risky=risky16; monitor=monitor16; OUTPUT;
occasion=17; age=age17; risky=risky17; monitor=monitor17; OUTPUT;
occasion=18; age=age18; risky=risky18; monitor=monitor18; OUTPUT;
* Drop old unnecessary multivariate variables;
DROP age12-age18 risky12-risky18 monitor12-monitor18;
LABEL   
occasion = "occasion: Occasion of Measurement (12-18)"
age = "age: Exact Age at Occasion"
risky = "risky: Risky Behavior at Occasion"
monitor = "monitor: Monitoring at Occasion";
RUN;

* Center predictors for analysis in stacked data;
DATA work.Example4; SET work.Example4;
agec18 = age - 18;
att4 = attitude12 - 4;
mon3 = monitor - 3;
agesq = agec18*agec18;
LABEL
agec18 = "agec18: Exact Age (0=18)"
agesq = "agesq: Squared Exact Age (0=18)"
att4 = "att4: Age 12 Attitudes (0=4)"
mon3 = "mon3: Monitoring (0=3)";
* Subset sample to complete cases for all predictors;
IF NMISS(agec18, att4, risky, monitor)>0 THEN DELETE;
RUN;

* Create double-stacked dataset for multivariate analysis;
* Also create dummy codes to serve as intercepts if needed;
DATA work.Example4doublestack; SET work.Example4;
DV="1risky  "; dvR=1; dvM=0; outcome=risky; OUTPUT;
DV="2monitor"; dvR=0; dvM=1; outcome=mon3;  OUTPUT;
LABEL
DV = "DV: Categorical indicator for which DV the row is for"
dvR = "dvR: Intercept 1=risky, 0=monitor"
dvM = "dvM: Intercept 0=risky, 1=monitor"
outcome = "outcome: Combined outcome variable column";
RUN;

* Save SAS syntax and output to permanent text file;
PROC PRINTTO PRINT="&example.\Example4_SAS_Output.txt" 
             LOG=  "&example.\Example4_SAS_Output.txt"; RUN;

TITLE1 'Ch 9 Eq 9.3: Multivariate Model of Risky Behavior and Monitoring';
TITLE2 'Tricking Univariate Software';
PROC MIXED DATA=work.Example4doublestack COVTEST NOCLPRINT NAMELEN=100 IC METHOD=ML;
     CLASS PersonID occasion DV;
     MODEL outcome = dvR dvM dvR*agec18 dvM*agec18 dvR*agec18*agec18 
                     dvR*att4 dvR*agec18*att4 dvM*att4 dvM*agec18*att4
                       / NOINT SOLUTION DDFM=Satterthwaite;
     RANDOM dvR dvM dvR*agec18 dvM*agec18 / G GCORR TYPE=UN SUBJECT=PersonID;
     REPEATED DV / R RCORR TYPE=UN SUBJECT=PersonID*occasion;
RUN; TITLE1; TITLE2;

* Close output;
PROC PRINTTO; RUN;


* Trimming data to send just needed variables to Mplus;
DATA work.Example4Mplus; SET work.Example4; 
* Telling it which variables to keep -- handy to use this in Mplus;
  KEEP PersonID occasion risky agec18 att4 mon3 agesq;
* Replace any missing values with -999;
  ARRAY avars(7) PersonID occasion risky agec18 att4 agesq mon3;
     DO i=1 TO 7; IF avars(i)=. THEN avars(i)=-999; END; DROP i;
RUN;

* Export to .csv for use in Mplus MLM syntax;
PROC EXPORT DATA=work.Example4Mplus OUTFILE= "&example.\Example4.csv" 
	DBMS=CSV REPLACE; PUTNAMES=NO; RUN;

* Trimming data to send just needed variables to Mplus;
DATA work.Example4Mplus; SET work.Example4; 
* Telling it which variables to keep -- handy to use this in Mplus;
  KEEP PersonID occasion risky agec18 att4 mon3 agesq;
RUN;
* Create lagged variables;
PROC EXPAND DATA=work.Example4Mplus OUT=work.Example4Lag;
	BY PersonID; ID occasion;  * Old = new name;
	CONVERT risky=LagRisky / METHOD=NONE TRANSFORMOUT=(LAG 1);
     CONVERT mon3=LagMon3   / METHOD=NONE TRANSFORMOUT=(LAG 1); RUN;
* Move lagged variables to end;
DATA work.Example4Lag; RETAIN PersonID occasion risky agec18 att4 mon3 agesq LagRisky LagMon3;
	SET work.Example4Lag; RUN;
* Create filter to keep cases with missing lagged predictors;
DATA work.Example4LagMplus; SET work.Example4Lag; 
  IF occasion=12 THEN Use12=0; ELSE Use12=1;
* Replace any missing values with -999;
  ARRAY avars(10) PersonID occasion risky agec18 att4 mon3 LagRisky LagMon3 agesq Use12;
     DO i=1 TO 10; IF avars(i)=. THEN avars(i)=-999; END; DROP i;
* Replace missing lagged variables with 0 to keep them;
 IF occasion=12 THEN DO; LagRisky=0; LagMon3=0; END; 
RUN;

* Export to .csv for use in Mplus MLM syntax;
PROC EXPORT DATA=work.Example4LagMplus OUTFILE= "&example.\Example4Lag.csv" 
	DBMS=CSV REPLACE; PUTNAMES=NO; RUN;
