* Encoding: UTF-8.
* Stop syntax and large titles from printing to output.
SET PRINTBACK=NONE HEADER=NO.

***********************************************************************************.
*******      BEGIN DATA MANIPULATION OF EXAMPLE 1 (Using CHAPTER 7b)        *******.
*******               CHANGE "example" to your directory                    *******.
***********************************************************************************.

* Define location of files used in code below.
FILE HANDLE example /NAME = "C:\Dropbox\Workshop_OSU_2018\Download\SPSS".

* Import chapter 7 multivariate data.
GET FILE = "example/Example1.sav".
DATASET NAME Example1multiv WINDOW=FRONT.
EXECUTE.

* Open output directory.
OUTPUT NAME Example1_SPSS_Output.

DATASET ACTIVATE Example1multiv.
* Stack multivariate data.
VARSTOCASES
   /MAKE age FROM age12 TO age18
   /MAKE risky FROM risky12 TO risky18
   /MAKE monitor FROM monitor12 TO monitor18
   /INDEX = wave (7)
   /KEEP = ALL.
DATASET NAME Example1 WINDOW=FRONT.
COMPUTE occasion = wave + 11.
VARIABLE LABELS 
wave "wave: Wave of Study (1-7)"
occasion "occasion: Occasion of Measurement (12-18)"
age "age: Exact Age at Occasion"
risky "risky: Risky Behavior at Occasion"
monitor "monitor: Monitoring at Occasion".

* Center predictors for analysis in stacked data.
COMPUTE agec18 = age - 18.
COMPUTE att4 = attitude12 - 4.
VARIABLE LABELS  
agec18 "agec18: Exact Age (0=18)"
att4 "att4: Age 12 Attitudes (0=4)".
* Subset sample to complete cases for all eventual predictors in chapter 9.
SELECT IF NVALID(agec18, att4, risky, monitor)=4.
EXECUTE.

***********************************************************************************.
*******                   BEGIN EXAMPLE 1 MODELS                            *******.
***********************************************************************************.
 
DATASET ACTIVATE Example1 WINDOW=FRONT.
ECHO 'SPSS Model 0: Saturated Means by Rounded Occasion, Unstructured Variance Model'.
MIXED risky BY PersonID occasion
     /METHOD   = ML
     /PRINT    = SOLUTION TESTCOV R 
     /FIXED    = occasion 
     /REPEATED = occasion | COVTYPE(UN) SUBJECT(PersonID)
     /EMMEANS  = TABLES(occasion) COMPARE(occasion)
.

DATASET ACTIVATE Example1 WINDOW=FRONT.
ECHO 'SPSS Model 1: Empty Means, Random Intercept Model'.
MIXED risky BY PersonID
     /METHOD   = ML
     /PRINT    = SOLUTION TESTCOV 
     /FIXED    =  
     /RANDOM   = INTERCEPT | COVTYPE(UN) SUBJECT(PersonID)
.
 
DATASET ACTIVATE Example1 WINDOW=FRONT.
ECHO 'SPSS Model 2a: Fixed Linear Age, Random Intercept Model'.
MIXED risky BY PersonID WITH agec18
     /METHOD   = ML
     /PRINT    = SOLUTION TESTCOV 
     /FIXED    = agec18 
     /RANDOM   = INTERCEPT | COVTYPE(UN) SUBJECT(PersonID)
     /TEST     = 'Intercept at Age=12' intercept 1 agec18 -6
     /TEST     = 'Intercept at Age=13' intercept 1 agec18 -5
     /TEST     = 'Intercept at Age=14' intercept 1 agec18 -4
     /TEST     = 'Intercept at Age=15' intercept 1 agec18 -3
     /TEST     = 'Intercept at Age=16' intercept 1 agec18 -2
     /TEST     = 'Intercept at Age=17' intercept 1 agec18 -1
     /TEST     = 'Intercept at Age=18' intercept 1 agec18  0
.
 
DATASET ACTIVATE Example1 WINDOW=FRONT.
ECHO 'SPSS Model 2b: Random Linear Age Model'.
MIXED risky BY PersonID WITH agec18
     /METHOD   = ML
     /PRINT    = SOLUTION TESTCOV 
     /FIXED    = agec18 
     /RANDOM   = INTERCEPT agec18 | COVTYPE(UN) SUBJECT(PersonID)
     /TEST     = 'Intercept at Age=12' intercept 1 agec18 -6
     /TEST     = 'Intercept at Age=13' intercept 1 agec18 -5
     /TEST     = 'Intercept at Age=14' intercept 1 agec18 -4
     /TEST     = 'Intercept at Age=15' intercept 1 agec18 -3
     /TEST     = 'Intercept at Age=16' intercept 1 agec18 -2
     /TEST     = 'Intercept at Age=17' intercept 1 agec18 -1
     /TEST     = 'Intercept at Age=18' intercept 1 agec18  0
.
 
DATASET ACTIVATE Example1 WINDOW=FRONT.
ECHO 'SPSS Model 2c: Fixed Quadratic, Random Linear Age Model'.
MIXED risky BY PersonID WITH agec18
     /METHOD   = ML
     /PRINT    = SOLUTION TESTCOV 
     /FIXED    = agec18 agec18*agec18 
     /RANDOM   = INTERCEPT agec18 | COVTYPE(UN) SUBJECT(PersonID)
     /TEST     = 'Intercept at Age=12'           intercept 1 agec18 -6 agec18*agec18 36
     /TEST     = 'Intercept at Age=13'           intercept 1 agec18 -5 agec18*agec18 25
     /TEST     = 'Intercept at Age=14'           intercept 1 agec18 -4 agec18*agec18 16
     /TEST     = 'Intercept at Age=15'           intercept 1 agec18 -3 agec18*agec18 9
     /TEST     = 'Intercept at Age=16'           intercept 1 agec18 -2 agec18*agec18 4
     /TEST     = 'Intercept at Age=17'           intercept 1 agec18 -1 agec18*agec18 1
     /TEST     = 'Intercept at Age=18'           intercept 1 agec18 0  agec18*agec18 0
     /TEST     = 'Linear Slope at Age=12'        agec18 1 agec18*agec18 -12
     /TEST     = 'Linear Slope at Age=13'        agec18 1 agec18*agec18 -10
     /TEST     = 'Linear Slope at Age=14'        agec18 1 agec18*agec18 -8
     /TEST     = 'Linear Slope at Age=15'        agec18 1 agec18*agec18 -6
     /TEST     = 'Linear Slope at Age=16'        agec18 1 agec18*agec18 -4
     /TEST     = 'Linear Slope at Age=17'        agec18 1 agec18*agec18 -2
     /TEST     = 'Linear Slope at Age=18'        agec18 1 agec18*agec18  0
     /SAVE     = FIXPRED(PredAge)
.
CORRELATIONS risky PredAge.
 
DATASET ACTIVATE Example1 WINDOW=FRONT.
ECHO 'SPSS Model 2d: Random Quadratic Age Model'.
MIXED risky BY PersonID WITH agec18
     /METHOD   = ML
     /PRINT    = SOLUTION TESTCOV 
     /FIXED    = agec18 agec18*agec18 
     /RANDOM   = INTERCEPT agec18 agec18*agec18 | COVTYPE(UN) SUBJECT(PersonID)
     /TEST     = 'Intercept at Age=12'           intercept 1 agec18 -6 agec18*agec18 36
     /TEST     = 'Intercept at Age=13'           intercept 1 agec18 -5 agec18*agec18 25
     /TEST     = 'Intercept at Age=14'           intercept 1 agec18 -4 agec18*agec18 16
     /TEST     = 'Intercept at Age=15'           intercept 1 agec18 -3 agec18*agec18 9
     /TEST     = 'Intercept at Age=16'           intercept 1 agec18 -2 agec18*agec18 4
     /TEST     = 'Intercept at Age=17'           intercept 1 agec18 -1 agec18*agec18 1
     /TEST     = 'Intercept at Age=18'           intercept 1 agec18 0  agec18*agec18 0
     /TEST     = 'Linear Slope at Age=12'        agec18 1 agec18*agec18 -12
     /TEST     = 'Linear Slope at Age=13'        agec18 1 agec18*agec18 -10
     /TEST     = 'Linear Slope at Age=14'        agec18 1 agec18*agec18 -8
     /TEST     = 'Linear Slope at Age=15'        agec18 1 agec18*agec18 -6
     /TEST     = 'Linear Slope at Age=16'        agec18 1 agec18*agec18 -4
     /TEST     = 'Linear Slope at Age=17'        agec18 1 agec18*agec18 -2
     /TEST     = 'Linear Slope at Age=18'        agec18 1 agec18*agec18 0
.
 
DATASET ACTIVATE Example1 WINDOW=FRONT.
ECHO 'SPSS Model 3: Fixed Quadratic, Random Linear Age Model;'.
ECHO 'Attitudes Predicting Quadratic Age Slope'.
MIXED risky BY PersonID WITH agec18 att4
     /METHOD   = ML
     /PRINT    = SOLUTION TESTCOV 
     /FIXED    = agec18 agec18*agec18
                 att4 agec18*att4 agec18*agec18*att4 
     /RANDOM   = INTERCEPT agec18 | COVTYPE(UN) SUBJECT(PersonID)
     /SAVE     = FIXPRED(PredAttQuad)
.
CORRELATIONS risky PredAttQuad.
 
* Close and export output directory.
OUTPUT EXPORT
  /CONTENTS EXPORT=ALL LAYERS=PRINTSETTING MODELVIEWS=PRINTSETTING
  /DOC  DOCUMENTFILE="example\Example1_SPSS_Output.doc"
        NOTESCAPTIONS=YES WIDETABLES=SHRINK PAGEBREAKS=YES PAGESIZE=INCHES(8.5, 11.0) 
        TOPMARGIN=INCHES(0.5) BOTTOMMARGIN=INCHES(0.5) LEFTMARGIN=INCHES(0.5) RIGHTMARGIN=INCHES(0.5).
