* Encoding: UTF-8.
* Define locations of files used in examples -- CHANGE THIS.
FILE HANDLE example /NAME = "C:\Dropbox\Workshop_OSU_2018\Download\SPSS".

* SPSS code to import data and center predictors.
GET FILE = "example/Example2.sav".
DATASET NAME example1 WINDOW=FRONT.
COMPUTE PMnm0 = PMnegmood - 0.
COMPUTE WPnm  = negmood - PMnegmood.
COMPUTE TVnm0 = negmood - 0.
VARIABLE LABELS
  PMnm0 "PMnm0: Person Mean Negative Mood (0=0)"
  WPnm  "WPnm: Within-Person Negative Mood (0=PM)"
  TVnm0 "TVnm0: Time-Varying Negative Mood (0=0)"
  sexMW "sexMW: Participant Sex (0=M, 1=W)".
EXECUTE.

******************************************************************************
                           EXAMPLE 2 MODELS                             ******
******************************************************************************.

DATASET ACTIVATE Example2 WINDOW=FRONT.

* Open output directory.
OUTPUT NAME Example2_SPSS_Output.

*** PART 1: VARIANCE DECOMPOSITION.

ECHO "SPSS Model 1a: Empty Model for Daily Glucose Outcome".
MIXED lGlucAM BY ID day
 /METHOD = ML
 /PRINT  = SOLUTION TESTCOV
 /FIXED  = 
 /RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN)
 /REPEATED = day | SUBJECT(ID) COVTYPE(ID).

ECHO "SPSS Model 1b: Empty Model for Daily Negative Mood Predictor".
MIXED negmood BY ID day
 /METHOD = ML
 /PRINT  = SOLUTION TESTCOV
 /FIXED  = 
 /RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN)
 /REPEATED = day | SUBJECT(ID) COVTYPE(ID).

*** PART 2: PERSON-MEAN-CENTERING OF NEGATIVE MOOD TO PREDICT GLUCOSE.

ECHO "SPSS Model 2a: Fixed Effects of Negative Mood using PMC".
MIXED lGlucAM BY ID day WITH WPnm PMnm0
 /METHOD = ML
 /PRINT  = SOLUTION TESTCOV
 /FIXED  = WPnm PMnm0
 /RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN)
 /REPEATED = day | SUBJECT(ID) COVTYPE(ID)
 /SAVE = FIXPRED (predmood)
 /TEST = "Within-Person Mood Effect"    WPnm  1
 /TEST = "Between-Person Mood Effect"   PMnm0 1
 /TEST = "Contextual Mood Effect"       PMnm0 1 WPnm -1.
CORRELATIONS lGlucAM predmood.

ECHO "SPSS Model 2b: Random Effect of WP Negative Mood using PMC".
MIXED lglucAM BY ID day WITH WPnm PMnm0
 /METHOD = ML
 /PRINT  = SOLUTION TESTCOV
 /FIXED  = WPnm PMnm0
 /RANDOM = INTERCEPT WPnm | SUBJECT(ID) COVTYPE(UN)
 /REPEATED = day | SUBJECT(ID) COVTYPE(ID)
 /TEST = "Within-Person Mood Effect"    WPnm  1
 /TEST = "Between-Person Mood Effect"   PMnm0 1
 /TEST = "Contextual Mood Effect"       PMnm0 1 WPnm -1.

ECHO "SPSS Model 2c: Fixed Effects of Sex (0=M, 1=W) by PMC Negative Mood ".
MIXED lglucAM BY ID day WITH WPnm PMnm0 sexMW
 /METHOD = ML
 /PRINT  = SOLUTION TESTCOV
 /FIXED  = WPnm PMnm0 sexMW WPnm*sexMW PMnm0*sexMW 
 /RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN)
 /REPEATED = day | SUBJECT(ID) COVTYPE(ID)
 /SAVE = FIXPRED (predsex)
 /TEST = "Intercept: Men (Mood=0)"                intercept 1 sexMW 0
 /TEST = "Intercept: Women (Mood=0)"              intercept 1 sexMW 1
 /TEST = "Intercept: Women Diff (Mood=0)"         sexMW 1
 /TEST = "Within-Person Mood Effect: Men"         WPnm 1 WPnm*sexMW 0
 /TEST = "Within-Person Mood Effect: Women"       WPnm 1 WPnm*sexMW 1
 /TEST = "Within-Person Mood Effect: Women Diff"  WPnm*sexMW 1
 /TEST = "Between-Person Mood Effect: Men"        PMnm0 1 PMnm0*sexMW 0
 /TEST = "Between-Person Mood Effect: Women"      PMnm0 1 PMnm0*sexMW 1
 /TEST = "Between-Person Mood Effect: Women Diff" PMnm0*sexMW 1
 /TEST = "Contextual Mood Effect: Men"            PMnm0 1 PMnm0*sexMW 0 WPnm -1 WPnm*sexMW  0
 /TEST = "Contextual Mood Effect: Women"          PMnm0 1 PMnm0*sexMW 1 WPnm -1 WPnm*sexMW -1
 /TEST = "Contextual Mood Effect: Women Diff"     PMnm0*sexMW 1 WPnm*sexMW -1.
CORRELATIONS lGlucAM predsex.


*** PART 3: GRAND-MEAN-CENTERING OF NEGATIVE MOOD TO PREDICT GLUCOSE.

ECHO "SPSS Model 3: Fixed Effect of TV Negative Mood only using GMC".
MIXED lglucAM BY ID day WITH TVnm0 
 /METHOD = ML
 /PRINT  = SOLUTION TESTCOV
 /FIXED  = TVnm0
 /RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN)
 /REPEATED = day | SUBJECT(ID) COVTYPE(ID).

ECHO "SPSS Model 3a: Fixed Effects of Negative Mood using GMC".
MIXED lglucAM BY ID day WITH TVnm0 PMnm0
 /METHOD = ML
 /PRINT  = SOLUTION TESTCOV
 /FIXED  = TVnm0 PMnm0
 /RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN)
 /REPEATED = day | SUBJECT(ID) COVTYPE(ID)
 /TEST = "Within-Person Mood Effect"    TVnm0 1
 /TEST = "Between-Person Mood Effect"   TVnm0 1 PMnm0 1
 /TEST = "Contextual Mood Effect"       PMnm0 1.

ECHO "SPSS Model 3b: Random Effect of TV Negative Mood using GMC".
MIXED lglucAM BY ID day WITH TVnm0 PMnm0
 /METHOD = ML
 /PRINT  = SOLUTION TESTCOV
 /FIXED  = TVnm0 PMnm0
 /RANDOM = INTERCEPT TVnm0 | SUBJECT(ID) COVTYPE(UN)
 /REPEATED = day | SUBJECT(ID) COVTYPE(ID)
 /TEST = "Within-Person Mood Effect"   TVnm0 1
 /TEST = "Between-Person Mood Effect"  TVnm0 1 PMnm0 1
 /TEST = "Contextual Mood Effect"      PMnm0 1.

ECHO "SPSS Model 3c: Fixed Effects of Sex (0=M, 1=W) by GMC Negative Mood".
MIXED lglucAM BY ID day WITH TVnm0 PMnm0 sexMW
 /METHOD = ML
 /PRINT  = SOLUTION TESTCOV
 /FIXED  = TVnm0 PMnm0 sexMW TVnm0*sexMW PMnm0*sexMW 
 /RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN)
 /REPEATED = day | SUBJECT(ID) COVTYPE(ID)
 /TEST = "Intercept: Men (Mood=0)"                intercept 1 sexMW 0
 /TEST = "Intercept: Women (Mood=0)"              intercept 1 sexMW 1
 /TEST = "Intercept: Women Diff (Mood=0)"         sexMW 1
 /TEST = "Within-Person Mood Effect: Men"         TVnm0 1 TVnm0*sexMW 0
 /TEST = "Within-Person Mood Effect: Women"       TVnm0 1 TVnm0*sexMW 1
 /TEST = "Within-Person Mood Effect: Women Diff"  TVnm0*sexMW 1
 /TEST = "Between-Person Mood Effect: Men"        TVnm0 1 TVnm0*sexMW 0 PMnm0 1 PMnm0*sexMW 0
 /TEST = "Between-Person Mood Effect: Women"      TVnm0 1 TVnm0*sexMW 1 PMnm0 1 PMnm0*sexMW 1
 /TEST = "Between-Person Mood Effect: Women Diff" TVnm0*sexMW 1 PMnm0*sexMW 1
 /TEST = "Contextual Mood Effect: Men"            PMnm0 1 PMnm0*sexMW 0 
 /TEST = "Contextual Mood Effect: Women"          PMnm0 1 PMnm0*sexMW 1 
 /TEST = "Contextual Mood Effect: Women Diff"     PMnm0*sexMW 1.

* Close and export output directory.
OUTPUT EXPORT
  /CONTENTS EXPORT=ALL LAYERS=PRINTSETTING MODELVIEWS=PRINTSETTING
  /DOC  DOCUMENTFILE="example\Example2_SPSS_Output.doc"
        NOTESCAPTIONS=YES WIDETABLES=SHRINK PAGEBREAKS=YES PAGESIZE=INCHES(8.5, 11.0) 
        TOPMARGIN=INCHES(0.5) BOTTOMMARGIN=INCHES(0.5) LEFTMARGIN=INCHES(0.5) RIGHTMARGIN=INCHES(0.5).
