* Prevent "more" messages from appearing
set more off
* Control line length
set linesize 150

********************************************************************************
*******       BEGIN DATA MANIPULATION FOR EXAMPLE 1 (FROM CHAPTER 7b)    *******
*******               CHANGE "example" to your directory                 *******
********************************************************************************

* Defining global variable for file location to be replaced in code below
global example "C:\Dropbox\Workshop_OSU_2018\Download\STATA"

* Import and stack chapter7b multivariate data
* List time-varying variables first, i(level2ID) j(newtimeID)
use "$example\Example1.dta", clear
reshape long age risky monitor, i(personid) j(occasion)
label variable occasion "occasion: Occasion of Measurement (12-18)"
label variable age "age: Exact Age at Occasion"
label variable risky "risky: Risky Behavior at Occasion"
label variable monitor "monitor: Monitoring at Occasion"

* Center predictors for analysis in stacked data
gen agec18 = age - 18
gen agec18sq = agec18 * agec18
gen att4 = attitude12 - 4
label variable agec18 "agec18: Exact Age (0=18)"
label variable agec18sq "agec18sq: Exact Quadratic Age (0=18)"
label variable att4 "att4: Age 12 Attitudes (0=4)"

* Subset sample to complete cases for all eventual predictors in chapter 9
egen nummiss = rowmiss(agec18 att4 risky monitor)
drop if nummiss>0

********************************************************************************
*******                   BEGIN EXAMPLE 1 MODELS                         *******
********************************************************************************

* Save results to separate file
log using $example\Example1_STATA_Output.log, replace

display as result "STATA Model 0: Saturated Means by Rounded Occasion, Unstructured Variance Model"
mixed risky i.occasion, ///
              || personid: , noconstant variance mle covariance(unstructured) ///
              residuals(unstructured,t(occasion)),
      estat ic, n(200),
      estat wcorrelation, covariance,
      estat wcorrelation,
      contrast i.occasion, 
      margins  i.occasion, 
      margins  i.occasion, pwcompare(pveffects)
	  
display as result "STATA Model 1: Empty Means, Random Intercept Model" 
mixed risky , || personid: , variance mle covariance(unstructured), 
      estat ic, n(200), 
      estat icc, 
      estat wcorrelation, covariance, 
      estat wcorrelation, 

display as result "STATA Model 2a: Fixed Linear Age, Random Intercept Model"
mixed risky c.agec18, ///
              || personid: , variance mle covariance(unstructured),
      estat ic, n(200),
      * Intercept at Age=12
      lincom _cons*1 + c.agec18*-6
      * Intercept at Age=13
      lincom _cons*1 + c.agec18*-5
      * Intercept at Age=14
      lincom _cons*1 + c.agec18*-4
      * Intercept at Age=15
      lincom _cons*1 + c.agec18*-3
      * Intercept at Age=16
      lincom _cons*1 + c.agec18*-2
      * Intercept at Age=17
      lincom _cons*1 + c.agec18*-1
      * Intercept at Age=18
      lincom _cons*1 + c.agec18*0
      estimates store FitFixLin,

display as result "STATA Model 2b: Random Linear Age Model" 
mixed risky c.agec18, ///
              || personid: agec18, variance mle covariance(unstructured),
      estat ic, n(200),
      * Intercept at Age=12
      lincom _cons*1 + c.agec18*-6
      * Intercept at Age=13
      lincom _cons*1 + c.agec18*-5
      * Intercept at Age=14
      lincom _cons*1 + c.agec18*-4
      * Intercept at Age=15
      lincom _cons*1 + c.agec18*-3
      * Intercept at Age=16
      lincom _cons*1 + c.agec18*-2
      * Intercept at Age=17
      lincom _cons*1 + c.agec18*-1
      * Intercept at Age=18
      lincom _cons*1 + c.agec18*0
      estimates store FitRandLin,
      lrtest FitRandLin FitFixLin, 

display as result "STATA Model 2c: Fixed Quadratic, Random Linear Age Model"
mixed risky c.agec18 c.agec18#c.agec18, ///
              || personid: agec18, variance mle covariance(unstructured),
      estat ic, n(200),
      * Intercept at Age=12
      lincom _cons*1 + c.agec18*-6 + c.agec18#c.agec18*36
      * Intercept at Age=13
      lincom _cons*1 + c.agec18*-5 + c.agec18#c.agec18*25
      * Intercept at Age=14
      lincom _cons*1 + c.agec18*-4 + c.agec18#c.agec18*16
      * Intercept at Age=15
      lincom _cons*1 + c.agec18*-3 + c.agec18#c.agec18*9
      * Intercept at Age=16
      lincom _cons*1 + c.agec18*-2 + c.agec18#c.agec18*4
      * Intercept at Age=17
      lincom _cons*1 + c.agec18*-1 + c.agec18#c.agec18*1
      * Intercept at Age=18
      lincom _cons*1 + c.agec18*0  + c.agec18#c.agec18*0
      * Linear Slope at Age=12
      lincom c.agec18*1 + c.agec18#c.agec18*-12
      * Linear Slope at Age=13
      lincom c.agec18*1 + c.agec18#c.agec18*-10
      * Linear Slope at Age=14
      lincom c.agec18*1 + c.agec18#c.agec18*-8
      * Linear Slope at Age=15
      lincom c.agec18*1 + c.agec18#c.agec18*-6
      * Linear Slope at Age=16
      lincom c.agec18*1 + c.agec18#c.agec18*-4
      * Linear Slope at Age=17
      lincom c.agec18*1 + c.agec18#c.agec18*-2
      * Linear Slope at Age=18
      lincom c.agec18*1 + c.agec18#c.agec18*0
      estimates store FitFixQuad,
      predict PredAge, xb,
corr risky PredAge

display as result "STATA Model 2d: Random Quadratic Age Model" 
mixed risky c.agec18 c.agec18#c.agec18, ///
              || personid: agec18 agec18sq, variance mle covariance(unstructured),
      estat ic, n(200),
      * Intercept at Age=12
      lincom _cons*1 + c.agec18*-6 + c.agec18#c.agec18*36
      * Intercept at Age=13
      lincom _cons*1 + c.agec18*-5 + c.agec18#c.agec18*25
      * Intercept at Age=14
      lincom _cons*1 + c.agec18*-4 + c.agec18#c.agec18*16
      * Intercept at Age=15
      lincom _cons*1 + c.agec18*-3 + c.agec18#c.agec18*9
      * Intercept at Age=16
      lincom _cons*1 + c.agec18*-2 + c.agec18#c.agec18*4
      * Intercept at Age=17
      lincom _cons*1 + c.agec18*-1 + c.agec18#c.agec18*1
      * Intercept at Age=18
      lincom _cons*1 + c.agec18*0  + c.agec18#c.agec18*0
      * Linear Slope at Age=12
      lincom c.agec18*1 + c.agec18#c.agec18*-12
      * Linear Slope at Age=13
      lincom c.agec18*1 + c.agec18#c.agec18*-10
      * Linear Slope at Age=14
      lincom c.agec18*1 + c.agec18#c.agec18*-8
      * Linear Slope at Age=15
      lincom c.agec18*1 + c.agec18#c.agec18*-6
      * Linear Slope at Age=16
      lincom c.agec18*1 + c.agec18#c.agec18*-4
      * Linear Slope at Age=17
      lincom c.agec18*1 + c.agec18#c.agec18*-2
      * Linear Slope at Age=18
      lincom c.agec18*1 + c.agec18#c.agec18*0
      estimates store FitRandQuad,
      lrtest FitRandQuad FitFixQuad, 

display as result "STATA Model 3: Fixed Quadratic, Random Linear Age Model" 
display as result "Attitudes Predicting Quadratic Age Slope" 
mixed risky c.agec18 c.agec18#c.agec18 ///
            c.att4 c.agec18#c.att4 c.agec18#c.agec18#c.att4, ///
              || personid: agec18, variance mle covariance(unstructured),
      estat ic, n(200),
      predict PredAttQuad, xb,
corr risky PredAttQuad

* Close log
log close

